@@ -7,14 +7,17 @@ import sys
 import base64
 import datetime
 import os
+from azure.storage.blob import BlobServiceClient, ContentSettings
 
 from cimetrics.env import get_env
 
 # Always the same for metrics-devops
-IMAGE_BRANCH_NAME = "cimetrics"
 IMAGE_PATH = "_cimetrics/diff.png"
 COMMENT_PATH = "_cimetrics/diff.txt"
 
+AZURE_BLOB_URL = os.getenv("AZURE_BLOB_URL")
+AZURE_WEB_URL = os.getenv("AZURE_WEB_URL")
+
 
 class GithubPRPublisher(object):
     def __init__(self):
@@ -29,42 +32,18 @@ class GithubPRPublisher(object):
         self.github_url = f"https://api.github.com/repos/{self.env.repo_id}"
         self.pull_request_id = self.env.pull_request_id
 
-    def create_image_branch(self):
-        # Does not do anything if the branch already exists
-        params = {}
-        params["ref"] = f"refs/heads/{IMAGE_BRANCH_NAME}"
-        rep = requests.get(
-            f"{self.github_url}/git/refs/heads/main",
-            data="",
-            headers=self.request_header,
+    def upload_image_as_blob(self, contents):
+        service = BlobServiceClient(account_url=AZURE_BLOB_URL)
+        name = f"plot-{self.env.repo_name.replace('/', '-')}-{self.env.pull_request_id}.png"
+        blob = service.get_blob_client(container="$web", blob=name)
+        blob.upload_blob(
+            contents,
+            overwrite=True,
+            content_settings=ContentSettings(
+                content_type="image/png", cache_control="no-cache"
+            ),
         )
-        json_rep = json.loads(rep.text)
-        params["sha"] = json_rep["object"]["sha"]
-
-        print(f"Creating branch {json.dumps(params)}")
-        rep = requests.post(
-            f"{self.github_url}/git/refs",
-            data=json.dumps(params),
-            headers=self.request_header,
-        )
-
-    def upload_image(self, encoded_image):
-        params = {}
-        params["message"] = "Uploading an image"
-        params["branch"] = IMAGE_BRANCH_NAME
-        params["content"] = encoded_image
-
-        print(f"Uploading image to branch {IMAGE_BRANCH_NAME}")
-        rep = requests.put(
-            f"{self.github_url}/contents/{IMAGE_BRANCH_NAME}/image{datetime.datetime.now()}.png",
-            data=json.dumps(params),
-            headers=self.request_header,
-        )
-        json_rep = json.loads(rep.text)
-        if "content" in json_rep:
-            return json_rep["content"]["download_url"]
-        else:
-            raise Exception("Failed to upload image")
+        return f"{AZURE_WEB_URL}/{name}"
 
     def first_self_comment(self):
         rep = requests.get(
@@ -110,14 +89,17 @@ if __name__ == "__main__":
 
     publisher = GithubPRPublisher()
 
-    publisher.create_image_branch()
-
     encoded_image = None
+    raw_image = None
     with open(os.path.join(env.repo_root, IMAGE_PATH), "rb") as image_file:
-        encoded_image = base64.b64encode(image_file.read())
+        raw_image = image_file.read()
+        encoded_image = base64.b64encode(raw_image)
     comment = ""
     with open(os.path.join(env.repo_root, COMMENT_PATH), "r") as comment_file:
         comment = comment_file.read()
 
-    image_url = publisher.upload_image(str(encoded_image.decode()))
+    assert (
+        AZURE_BLOB_URL and AZURE_WEB_URL
+    ), "Either AZURE_BLOB_URL or AZURE_WEB_URL is not set"
+    image_url = publisher.upload_image_as_blob(raw_image)
     publisher.publish_comment(image_url, comment)
